@@ -1,15 +1,16 @@
 # Initialize google spreadsheet constants
-from pathlib import Path
 from configparser import ConfigParser
+from pathlib import Path
 
 from .config_util import init_config_file
 
 config_gsheet = None
 
+
 def init_constants():
-    '''initialize all constants'''
+    """initialize all constants"""
     global config_gsheet
-    template_name = 'google_sheet.ini'
+    template_name = "google_sheet.ini"
     cfile = "gsheet_config.ini"
 
     if not Path(cfile).exists():
@@ -19,4 +20,4 @@ def init_constants():
     config.read(cfile)
 
     # export global variables
-    config_gsheet = dict(config['google_spreadsheet'])
+    config_gsheet = dict(config["google_spreadsheet"])
